Chemical equation
=================

Use the ChemicalEquation class to determine properties of the reactants and
products in a given chemical equation.

.. autoclass:: chemics.ChemicalEquation
   :members:
